==> ejc-zjkjcost-impl-3.0.0-20220629.032646-20-sources.jar: com/ejianc/business/zjkjcost/node/bean/NodeApprovalEntity.java <==
package com.ejianc.business.zjkjcost.node.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 节点考核-工程项目节点目标奖金审批
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_node_approval")
public class NodeApprovalEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目编号
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 项目部编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 项目部上级组织编码
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_code")
    private String contractCode; // 合同编号
    @TableField(value="assess_id")
    private Long assessId; // 根据目标责任书约定执行
    @TableField(value="assess_code")
    private String assessCode; // 考核单据编号
    @TableField(value="assess_name")
    private String assessName; // 考核单据名称
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="apply_date")
    private Date applyDate; // 申请日期
    @TableField(value="apply_mny")
    private BigDecimal applyMny; // 申报金额
    @TableField(value="book_id")
    private Long bookId; // 项目目标管理责任书id
    @TableField(value="book_name")
    private String bookName; // 项目目标管理责任书名称
    @TableField(value="book_code")
    private String bookCode; // 项目目标管理责任书单据编号
    @TableField(value="project_node")
    private String projectNode; // 工程项目节点
    @TableField(value="basis_content")
    private String basisContent; // 依据
    @TableField(value="bonus_calculation")
    private String bonusCalculation; // 该项目的节点目标奖金计算如下
    @TableField(value="bonus_mny")
    private BigDecimal bonusMny; // 节点目标奖金
    @TableField(value="finance_deduction_mny")
    private BigDecimal financeDeductionMny; // 所属单位财务资金部门扣款金额
    @TableField(value="security_deduction_mny")
    private BigDecimal securityDeductionMny; // 所属单位安全生产监督管理部扣款金额
    @TableField(value="technology_deduction_mny")
    private BigDecimal technologyDeductionMny; // 所属单位工程技术研究中心扣款金额
    @TableField(value="department_cash_mny")
    private BigDecimal departmentCashMny; // 所属单位建造管理部意见兑现金额
    @TableField(value="leader_cash_mny")
    private BigDecimal leaderCashMny; // 所属单位分管领导兑现金额
    @TableField(value="manager_cash_mny")
    private BigDecimal managerCashMny; // 所属单位总经理兑现金额
    @TableField(value="chairman_cash_mny")
    private BigDecimal chairmanCashMny; // 所属单位董事长兑现金额
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public Long getAssessId() {
        return assessId;
    }

    public void setAssessId(Long assessId) {
        this.assessId = assessId;
    }
    public String getAssessCode() {
        return assessCode;
    }

    public void setAssessCode(String assessCode) {
        this.assessCode = assessCode;
    }
    public String getAssessName() {
        return assessName;
    }

    public void setAssessName(String assessName) {
        this.assessName = assessName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public Date getApplyDate() {
        return applyDate;
    }

    public void setApplyDate(Date applyDate) {
        this.applyDate = applyDate;
    }
    public BigDecimal getApplyMny() {
        return applyMny;
    }

    public void setApplyMny(BigDecimal applyMny) {
        this.applyMny = applyMny;
    }
    public Long getBookId() {
        return bookId;
    }

    public void setBookId(Long bookId) {
        this.bookId = bookId;
    }
    public String getBookName() {
        return bookName;
    }

    public void setBookName(String bookName) {
        this.bookName = bookName;
    }
    public String getBookCode() {
        return bookCode;
    }

    public void setBookCode(String bookCode) {
        this.bookCode = bookCode;
    }
    public String getProjectNode() {
        return projectNode;
    }

    public void setProjectNode(String projectNode) {
        this.projectNode = projectNode;
    }
    public String getBasisContent() {
        return basisContent;
    }

    public void setBasisContent(String basisContent) {
        this.basisContent = basisContent;
    }
    public String getBonusCalculation() {
        return bonusCalculation;
    }

    public void setBonusCalculation(String bonusCalculation) {
        this.bonusCalculation = bonusCalculation;
    }
    public BigDecimal getBonusMny() {
        return bonusMny;
    }

    public void setBonusMny(BigDecimal bonusMny) {
        this.bonusMny = bonusMny;
    }
    public BigDecimal getFinanceDeductionMny() {
        return financeDeductionMny;
    }

    public void setFinanceDeductionMny(BigDecimal financeDeductionMny) {
        this.financeDeductionMny = financeDeductionMny;
    }
    public BigDecimal getSecurityDeductionMny() {
        return securityDeductionMny;
    }

    public void setSecurityDeductionMny(BigDecimal securityDeductionMny) {
        this.securityDeductionMny = securityDeductionMny;
    }
    public BigDecimal getTechnologyDeductionMny() {
        return technologyDeductionMny;
    }

    public void setTechnologyDeductionMny(BigDecimal technologyDeductionMny) {
        this.technologyDeductionMny = technologyDeductionMny;
    }
    public BigDecimal getDepartmentCashMny() {
        return departmentCashMny;
    }

    public void setDepartmentCashMny(BigDecimal departmentCashMny) {
        this.departmentCashMny = departmentCashMny;
    }
    public BigDecimal getLeaderCashMny() {
        return leaderCashMny;
    }

    public void setLeaderCashMny(BigDecimal leaderCashMny) {
        this.leaderCashMny = leaderCashMny;
    }
    public BigDecimal getManagerCashMny() {
        return managerCashMny;
    }

    public void setManagerCashMny(BigDecimal managerCashMny) {
        this.managerCashMny = managerCashMny;
    }
    public BigDecimal getChairmanCashMny() {
        return chairmanCashMny;
    }

    public void setChairmanCashMny(BigDecimal chairmanCashMny) {
        this.chairmanCashMny = chairmanCashMny;
    }
    
}

==> ejc-zjkjcost-impl-3.0.0-20221019.100803-59-sources.jar: com/ejianc/business/zjkjcost/node/bean/NodeApprovalEntity.java <==
package com.ejianc.business.zjkjcost.node.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 节点考核-工程项目节点目标奖金审批
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_node_approval")
public class NodeApprovalEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目编号
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 项目部编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 项目部上级组织编码
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_code")
    private String contractCode; // 合同编号
    @TableField(value="assess_id")
    private Long assessId; // 根据目标责任书约定执行
    @TableField(value="assess_code")
    private String assessCode; // 考核单据编号
    @TableField(value="assess_name")
    private String assessName; // 考核单据名称
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="apply_date")
    private Date applyDate; // 申请日期
    @TableField(value="apply_mny")
    private BigDecimal applyMny; // 申报金额
    @TableField(value="book_id")
    private Long bookId; // 项目目标管理责任书id
    @TableField(value="book_name")
    private String bookName; // 项目目标管理责任书名称
    @TableField(value="book_code")
    private String bookCode; // 项目目标管理责任书单据编号
    @TableField(value="project_node")
    private String projectNode; // 工程项目节点
    @TableField(value="basis_content")
    private String basisContent; // 依据
    @TableField(value="bonus_calculation")
    private String bonusCalculation; // 该项目的节点目标奖金计算如下
    @TableField(value="bonus_mny")
    private BigDecimal bonusMny; // 节点目标奖金
    @TableField(value="finance_deduction_mny")
    private BigDecimal financeDeductionMny; // 所属单位财务资金部门扣款金额
    @TableField(value="security_deduction_mny")
    private BigDecimal securityDeductionMny; // 所属单位安全生产监督管理部扣款金额
    @TableField(value="technology_deduction_mny")
    private BigDecimal technologyDeductionMny; // 所属单位工程技术研究中心扣款金额
    @TableField(value="department_cash_mny")
    private BigDecimal departmentCashMny; // 所属单位建造管理部意见兑现金额
    @TableField(value="leader_cash_mny")
    private BigDecimal leaderCashMny; // 所属单位分管领导兑现金额
    @TableField(value="manager_cash_mny")
    private BigDecimal managerCashMny; // 所属单位总经理兑现金额
    @TableField(value="chairman_cash_mny")
    private BigDecimal chairmanCashMny; // 所属单位董事长兑现金额
    @TableField(value="calculation_basis_content")
    private String calculationBasisContent;

    public String getCalculationBasisContent() {
        return calculationBasisContent;
    }

    public void setCalculationBasisContent(String calculationBasisContent) {
        this.calculationBasisContent = calculationBasisContent;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public Long getAssessId() {
        return assessId;
    }

    public void setAssessId(Long assessId) {
        this.assessId = assessId;
    }
    public String getAssessCode() {
        return assessCode;
    }

    public void setAssessCode(String assessCode) {
        this.assessCode = assessCode;
    }
    public String getAssessName() {
        return assessName;
    }

    public void setAssessName(String assessName) {
        this.assessName = assessName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public Date getApplyDate() {
        return applyDate;
    }

    public void setApplyDate(Date applyDate) {
        this.applyDate = applyDate;
    }
    public BigDecimal getApplyMny() {
        return applyMny;
    }

    public void setApplyMny(BigDecimal applyMny) {
        this.applyMny = applyMny;
    }
    public Long getBookId() {
        return bookId;
    }

    public void setBookId(Long bookId) {
        this.bookId = bookId;
    }
    public String getBookName() {
        return bookName;
    }

    public void setBookName(String bookName) {
        this.bookName = bookName;
    }
    public String getBookCode() {
        return bookCode;
    }

    public void setBookCode(String bookCode) {
        this.bookCode = bookCode;
    }
    public String getProjectNode() {
        return projectNode;
    }

    public void setProjectNode(String projectNode) {
        this.projectNode = projectNode;
    }
    public String getBasisContent() {
        return basisContent;
    }

    public void setBasisContent(String basisContent) {
        this.basisContent = basisContent;
    }
    public String getBonusCalculation() {
        return bonusCalculation;
    }

    public void setBonusCalculation(String bonusCalculation) {
        this.bonusCalculation = bonusCalculation;
    }
    public BigDecimal getBonusMny() {
        return bonusMny;
    }

    public void setBonusMny(BigDecimal bonusMny) {
        this.bonusMny = bonusMny;
    }
    public BigDecimal getFinanceDeductionMny() {
        return financeDeductionMny;
    }

    public void setFinanceDeductionMny(BigDecimal financeDeductionMny) {
        this.financeDeductionMny = financeDeductionMny;
    }
    public BigDecimal getSecurityDeductionMny() {
        return securityDeductionMny;
    }

    public void setSecurityDeductionMny(BigDecimal securityDeductionMny) {
        this.securityDeductionMny = securityDeductionMny;
    }
    public BigDecimal getTechnologyDeductionMny() {
        return technologyDeductionMny;
    }

    public void setTechnologyDeductionMny(BigDecimal technologyDeductionMny) {
        this.technologyDeductionMny = technologyDeductionMny;
    }
    public BigDecimal getDepartmentCashMny() {
        return departmentCashMny;
    }

    public void setDepartmentCashMny(BigDecimal departmentCashMny) {
        this.departmentCashMny = departmentCashMny;
    }
    public BigDecimal getLeaderCashMny() {
        return leaderCashMny;
    }

    public void setLeaderCashMny(BigDecimal leaderCashMny) {
        this.leaderCashMny = leaderCashMny;
    }
    public BigDecimal getManagerCashMny() {
        return managerCashMny;
    }

    public void setManagerCashMny(BigDecimal managerCashMny) {
        this.managerCashMny = managerCashMny;
    }
    public BigDecimal getChairmanCashMny() {
        return chairmanCashMny;
    }

    public void setChairmanCashMny(BigDecimal chairmanCashMny) {
        this.chairmanCashMny = chairmanCashMny;
    }
    
}
